# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_without repolib

%define reltag B1
%define version_full %{version}.%{reltag}

%define repodir %{_javadir}/repository.jboss.com/facelets/%{version_full}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free

Name:           facelets
Version:        1.1.15
Release:        1.%{reltag}.1%{?dist}
Epoch:          0
Summary:        JavaServer Faces View Definition Framework
License:        ASL 2.0
Group:          Development/Libraries/Java
URL:            https://facelets.dev.java.net/
# cvs -Q -d :pserver:guest@cvs.dev.java.net:/cvs export -d facelets-1.1.15 -r milestone_1-1-15-beta facelets && tar cjf facelets-1.1.15.tar.bz2 facelets-1.1.15
Source0:        facelets-%{version}.tar.bz2
Source1:        facelets-component-info.xml
Patch0:         https://facelets.dev.java.net/nonav/issues/showattachment.cgi/134/facelets-336.patch
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       jpackage-utils
BuildRequires:  ant
BuildRequires:  el_1_0_api
BuildRequires:  el-impl
BuildRequires:	glassfish-jsf
BuildRequires:  jpackage-utils
BuildRequires:  servlet_2_5_api
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildRequires:  java-devel
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The web community is eagerly seeking a framework like 
Tapestry, backed by JavaServer Faces as the industry 
standard. While JavaServer Faces and JSP are meant to 
be aligned,Facelets steps outside of the JSP spec and 
provides a highly performant, JSF-centric view technology. 
Anyone who has created a JSP page will be able to do the 
same with Facelets. The difference is under the hood where 
all the burden of the JSP Vendor API is removed to more 
greatly enhance JSF performance and provide easy plug-and-go 
development. Even though Facelets is being developed open 
source under Sun's guidance, it can work with any JSF 1.2 
compliant implementation or MyFaces. 

%package manual
Summary:        Manual for %{name}
Group:          Development/Java

%description manual
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q
pushd src/java/com/sun/facelets/impl
%patch0 -p0 -b .sav0
popd
%{_bindir}/find -type f -name "*.jar" | %{_bindir}/xargs -t %{__rm}

%{__mkdir} lib
%{__ln_s} $(build-classpath glassfish-jsf-api) lib/jsf-api-1.2_04-p02.jar
%{__ln_s} $(build-classpath servlet_2_5_api) lib/servlet-api-2.4.jar
%{__ln_s} $(build-classpath el_1_0_api) lib/el-api-1.0.jar
%{__ln_s} $(build-classpath el-impl) lib/el-impl-1.0.jar

%build
export CLASSPATH=
export OPT_JAR_LIST=:
%{ant} -Drelease.version=%{version_full}

%install
%{__rm} -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p dist/jsf-facelets.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%{__cp} -p dist/jsf-facelets.jar %{buildroot}%{_javadir}/jsf-facelets-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do %{__ln_s} ${jar} `/bin/echo ${jar} | %{__sed} "s|-%{version}||g"`; done)

# poms
%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -p jsf-facelets.pom $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
%{__sed} -i -e 's/@VERSION@/%{version_full}/' $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap com.sun.facelets jsf-facelets %{version_full} JPP %{name}

# javadoc
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__cp} -pr build/docs/api/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/jsf-facelets-%{version}
%{__ln_s} jsf-facelets-%{version} %{buildroot}%{_javadocdir}/jsf-facelets

%if %with repolib
%{__mkdir_p} %{buildroot}%{repodir}
%{__mkdir_p} %{buildroot}%{repodirlib}
%{__cp} -p %{SOURCE1} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{version_full}-brew/g" %{buildroot}%{repodir}/component-info.xml
%{__mkdir_p} %{buildroot}%{repodirsrc}
%{__cp} -p %{SOURCE0} %{buildroot}%{repodirsrc}
%{__cp} -p %{PATCH0} %{buildroot}%{repodirsrc}
%{__cp} -p %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom %{buildroot}%{repodirlib}/jsf-facelets.pom
%{__cp} -p %{buildroot}%{_javadir}/%{name}-%{version}.jar %{buildroot}%{repodirlib}/jsf-facelets.jar
%endif

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/jsf-facelets-%{version}.jar
%{_javadir}/jsf-facelets.jar
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/*
%endif
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%if 0
%doc build/%{name}%{archive_version}/docs/*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}
%{_javadocdir}/jsf-facelets-%{version}
%{_javadocdir}/jsf-facelets

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}
%{_javadir}/repository.jboss.com
%endif

%changelog
* Wed Nov 17 2010 David Walluck <dwalluck@redhat.com> 0:1.1.15-1.B1.1
- change repolib location

* Thu Oct 28 2010 David Walluck <dwalluck@redhat.com> 0:1.1.15-1.B1.0
- update Release

* Thu Sep 02 2010 David Walluck <dwalluck@redhat.com> 0:1.1.15-0.B1.5
- set release.version
- set pom and component-info version appropriately

* Wed Aug 25 2010 David Walluck <dwalluck@redhat.com> 0:1.1.15-0.b1.4
- apply patch for facelets issue #336
- add POM to repolib

* Wed Aug 25 2010 David Walluck <dwalluck@redhat.com> 0:1.1.15-0.b1.3
- remove Requires (not in POM and expect scope provided)
- fix POM
- fix GCJ support option

* Wed Jun 10 2009 Martha Benitez <mbenitez@redhat.com> 0:1.1.15-0.b1.2
- Change BR jsf_1_2_api to glassfish-jsf

* Tue Feb 03 2009 David Walluck <dwalluck@redhat.com> 0:1.1.15-0.b1.1
- 1.1.15 beta 1
- add repolib
- add jsf-facelets compatibility symlinks

* Tue Jan 20 2009 Ralph Apel <r.apel@r-apel.de> 0:1.1.14-2
- Fix depmap frag 

* Thu Dec 18 2008 Ralph Apel <r.apel@r-apel.de> 0:1.1.14-1
- First release
